@@ -3,6 +3,8 @@
 
 #include <QtCore/QCoreApplication>
 #include <QFile>
+#include <QFileDialog>
+#include <QDebug>
 
 MainWindow::MainWindow(QWidget *parent)
     : QMainWindow(parent), ui(new Ui::MainWindow)
@@ -386,39 +388,43 @@ void MainWindow::on_btnApply_clicked()
     }
 }
 
-void MainWindow::on_btnSave_clicked()
-{
-    QString customLevel;
+void MainWindow::drawLevel(){
+    /*
+		#########################################
+		# 0 empty
+		# 1 field
+		# 2 wall
+		# 3 destination
+		# 4 box
+		# 5 completed box
+		# 6 player
+		# 7 player on destination
+		#########################################
+		*/
 
-    QString name=QFileDialog::getSaveFileName(this,"Select a Custom Level","/home/user/MyDocs/", "Pusher Files (*.psh)");
-    if (name.indexOf(".psh")==-1){
-        name=name+".psh";
+    for (int j = 0;j < 16; ++j) {
+	for (int i = 0; i< 16; ++i) {
+	    if (images[i][j]->type == 0){
+		images[i][j]->setStyleSheet("");
+	    }else if (images[i][j]->type == 1){
+		images[i][j]->setStyleSheet("QLabel{ background-image: url(:/icons/fields/field_0.png);}");
+	    }else if (images[i][j]->type == 2){
+		images[i][j]->setStyleSheet("QLabel{ background-image: url(:/icons/walls/wall_0.png);}");
+	    }else if (images[i][j]->type == 3){
+		images[i][j]->setStyleSheet("QLabel{ background-image: url(:/icons/fields/field_0.png);image: url(:/icons/destinations/destination_0.png);}");
+	    }else if ( images[i][j]->type == 4){
+		images[i][j]->setStyleSheet("QLabel{ background-image: url(:/icons/fields/field_0.png);image: url(:/icons/boxes/box_0.png);}");
+	    }else if ( images[i][j]->type == 5) {
+		images[i][j]->setStyleSheet("QLabel{ background-image: url(:/icons/fields/field_0.png);image: url(:/icons/completedBoxes/completedBox_0.png);}");
+	    }else if ( images[i][j]->type == 6){
+		images[i][j]->setStyleSheet("QLabel{ background-image: url(:/icons/fields/field_0.png);image: url(:/icons/players/player_0.png);}");
+	    }else if ( images[i][j]->type == 7){
+		images[i][j]->setStyleSheet("QLabel{ background-image: url(:/icons/fields/field_0.png);image: url(:/icons/playersOnDestination/playerOnDestination_0.png);}");
+	    }else{
+		images[i][j]->setStyleSheet("");
+	    }
+	}
     }
-
-    QFile file(name);
-
-    if ( file.open(QIODevice::WriteOnly | QIODevice::Text) )
-    {
-        QTextStream stream( &file );
-
-        for (int x = 0; x < 16; ++x) {
-            customLevel="";
-            for (int y = 0; y < 16; ++y) {
-
-                if (customLevel.isEmpty()){
-                    customLevel="{"+QString::number(images[y][x]->type);
-                }else if (y==15){
-                    customLevel=customLevel+","+QString::number(images[y][x]->type);
-                    stream << customLevel << "}\n";
-                }else{
-                    customLevel=customLevel+","+QString::number(images[y][x]->type);
-                }
-            }
-        }
-    }
-
-    qDebug() << customLevel;
-
 }
 
 void MainWindow::on_btnSav_clicked()
@@ -454,3 +460,48 @@ void MainWindow::on_btnSav_clicked()
         file.close();
     }
 }
+
+void MainWindow::on_btnLoad_clicked()
+{
+    QString fullLine;
+    QString fileName = QFileDialog::getOpenFileName(this, tr("Open File"),"",tr("Pusher level file (*.psh)"));
+    QFile file(fileName);
+    if (!file.open(QIODevice::ReadOnly | QIODevice::Text)){
+	//showmessage that file is corrupted
+    }else{
+	QTextStream in(&file);
+	QString line = in.readLine();
+	QStringList lines;
+
+	line = line.remove('{');
+	line = line.remove('}');
+	line = line.remove(',');
+	lines.append(line);
+	fullLine=fullLine+line;
+
+	while (!line.isNull()) {
+	    line = in.readLine();
+	    line = line.remove('{');
+	    line = line.remove('}');
+	    line = line.remove(',');
+	    lines.append(line);
+	    fullLine=fullLine+line;
+	}
+
+	for (int var = 0; var < lines.count(); ++var) {
+	    qDebug() << lines.at(var);
+	}
+
+	if (lines.count()>15){
+	    for (int x = 0; x < 16; ++x) {
+		for (int y = 0; y < 16; ++y) {
+		    images[y][x]->type=QString(lines.at(x).at(y)).toInt();
+		}
+	    }
+	    drawLevel();
+	}else{
+	    //showmessage that file is corrupted
+	}
+
+    }
+}
